@@ -9,13 +9,15 @@
 // The client class provides a base class for classes that implement the client
 // side of a client-server communication model.
 
-class client : virtual public datatransport {
+class client : public filedescriptor {
 	public:
 
-		virtual void	initialize(namevaluepairs *cd)=0;
+			client();
+		virtual ~client();
 
+		virtual void	initialize(namevaluepairs *cd)=0;
 		virtual int	connect()=0;
-				// This method returns an int instead of a bool
+				// This method return an int instead of a bool
 				// because we want child classes that have non
 				// atomic connection procedures (such as a
 				// modem) to be able to implement return codes
