@@ -20,8 +20,10 @@ class parameterstring {
 			parameterstring();
 			~parameterstring();
 
+		void	setDelimiter(char delim);
 		bool	parse(const char *string);
 		char	*getValue(const char *name);
+		void	clear();
 
 	#include <rudiments/private/parameterstring.h>
 };
