@@ -2,8 +2,5 @@
 // See the COPYING file for more information
 
 	private:
-		char	*buffer;
-		size_t	size;
-
 		static	int	countLeadingSpaces(char *string, int length);
 		static	int	countTrailingSpaces(char *string, int length);
