@@ -2,5 +2,7 @@
 // See the COPYING file for more information.
 
 	protected:
+		long		timeoutsec;
+		long		timeoutusec;
 		unsigned int	retrywait;
 		unsigned int	retrycount;
