@@ -1,10 +1,10 @@
 // Copyright (c) 2000-2002 David Muse
 // See the COPYING file for more information.
 
-#include <rudiments/private/config.h>
-
 #include <rudiments/environment.h>
 
 #include <time.h>
 #include <sys/types.h>
-#include <pthread.h>
+#ifdef RUDIMENTS_HAS_THREADS
+	#include <pthread.h>
+#endif
