@@ -1,7 +1,14 @@
 // Copyright (c) 2002 David Muse
 // See the COPYING file for more information.
 
+#include <rudiments/private/config.h>
+
 #include <rudiments/resultcodes.h>
-#include <rudiments/listener.h>
 
 #include <sys/types.h>
+
+#ifdef RUDIMENTS_HAS_SSL
+	#include <openssl/ssl.h>
+#endif
+
+class listener;
