@@ -5,4 +5,6 @@
 
 #include <sys/types.h>
 #include <grp.h>
-#include <pthread.h>
+#ifdef RUDIMENTS_HAS_THREADS
+	#include <pthread.h>
+#endif
