@@ -6,8 +6,9 @@
 		hostent	hebuffer;
 		char	*buffer;
 
-		#if !defined(HAVE_GETHOSTBYNAME_R) || \
-				!defined(HAVE_GETHOSTBYADDR_R)
+		#if defined(RUDIMENTS_HAS_THREADS) && \
+			(!defined(HAVE_GETHOSTBYNAME_R) || \
+				!defined(HAVE_GETHOSTBYADDR_R))
 			static	pthread_mutex_t	*hemutex;
 		#endif
 
