@@ -6,7 +6,8 @@
 		passwd	pwdbuffer;
 		char	*buffer;
 
-		#if !defined(HAVE_GETPWNAM_R) || !defined(HAVE_GETPWUID_R)
+		#if defined(RUDIMENTS_HAS_THREADS) && \
+			(!defined(HAVE_GETPWNAM_R) || !defined(HAVE_GETPWUID_R))
 			static	pthread_mutex_t	*pemutex;
 		#endif
 
