@@ -3,6 +3,8 @@
 
 #include <rudiments/private/config.h>
 
-#include <pthread.h>
+#ifdef RUDIMENTS_HAS_THREADS
+	#include <pthread.h>
+#endif
 
 #include <netdb.h>
