@@ -6,8 +6,9 @@
 		servent		sebuffer;
 		char		*buffer;
 
-		#if !defined(HAVE_GETSERVBYNAME_R) || \
-				!defined(HAVE_GETSERVBYPORT_R)
+		#if defined(RUDIMENTS_HAS_THREADS) && \
+			(!defined(HAVE_GETSERVBYNAME_R) || \
+				!defined(HAVE_GETSERVBYPORT_R))
 			static	pthread_mutex_t	*semutex;
 		#endif
 
