@@ -6,6 +6,7 @@
 		spwd	spbuffer;
 		char	*buffer;
 
-		#if !defined(HAVE_GETSPNAM_R)
+		#if defined(RUDIMENTS_HAS_THREADS) && \
+			!defined(HAVE_GETSPNAM_R)
 			static	pthread_mutex_t	*spmutex;
 		#endif
