@@ -1,5 +1,5 @@
 // Copyright (c) 2002 David Muse
 // See the COPYING file for more information.
 
-#include <rudiments/client.h>
-#include <rudiments/private/unixsocket.h>
+#include <rudiments/clientsocket.h>
+#include <rudiments/unixsocketutil.h>
