@@ -2,6 +2,6 @@
 // See the COPYING file for more information.
 
 #include <rudiments/serversocket.h>
-#include <rudiments/private/unixsocket.h>
+#include <rudiments/unixsocketutil.h>
 
 #include <sys/types.h>
