@@ -2,6 +2,8 @@
 // See the COPYING file for more information.
 
 	protected:
+		void	init(unsigned char *initialcontents,
+				size_t initialsize, size_t increment);
 		void	extend(size_t size);
 
 		unsigned char	*buffer;
